@@ -44,11 +44,11 @@ function(object, specs, contr.list, trend, ...) {
     
     if(length(specs) == 2) { # just a rhs
         by = .find.by(as.character(specs[2]))
-        lsmeans(object, All.vars(specs), by = by, ...)
+        lsmeans(object, .all.vars(specs), by = by, ...)
     }
     else {
-#        lsms = lsmeans(object, All.vars(specs[-2]), ...)
-        contr.spec = All.vars(specs[-3])[1]
+#        lsms = lsmeans(object, .all.vars(specs[-2]), ...)
+        contr.spec = .all.vars(specs[-3])[1]
         by = .find.by(as.character(specs[3]))
         # Handle old-style case where contr is a list of lists
         if (!missing(contr.list)) {
@@ -56,7 +56,7 @@ function(object, specs, contr.list, trend, ...) {
             if (!is.null(cmat))
                 contr.spec = cmat
         }
-        lsmeans(object, specs = All.vars(specs[-2]), 
+        lsmeans(object, specs = .all.vars(specs[-2]), 
                 by = by, contr = contr.spec, ...)
     }
 }
@@ -123,6 +123,7 @@ lsmeans.character.ref.grid = function(object, specs, by = NULL,
     
     # Figure out the structure of the grid
     wgt = RG@grid[[".wgt."]]
+    if(all(zapsmall(wgt) == 0)) wgt = wgt + 1 ### repl all zero wgts with 1
     dims = sapply(RG@levels, length)
     row.idx = array(seq_len(nrow(RG@linfct)), dims)
     use.mars = match(facs, names(RG@levels)) # which margins to use
@@ -159,14 +160,14 @@ lsmeans.character.ref.grid = function(object, specs, by = NULL,
         if (is.matrix(weights)) {
             wtrow = 0
             fac.reduce = function(coefs) {
-                wtmat = diag(weights[wtrow+1, ]) / sum(weights[wtrow+1, ])
+                wtmat = .diag(weights[wtrow+1, ]) / sum(weights[wtrow+1, ])
                 ans = apply(wtmat %*% coefs, 2, sum)
                 wtrow <<- (1 + wtrow) %% nrow(weights)
                 ans
             }
         }
         else if (is.numeric(weights)) {
-            wtmat = diag(weights)
+            wtmat = .diag(weights)
             wtsum = sum(weights)
             if (wtsum <= 1e-8) wtsum = NA
             fac.reduce = function(coefs) {
@@ -188,7 +189,7 @@ lsmeans.character.ref.grid = function(object, specs, by = NULL,
     if (!missing(weights) && (weights == "fq"))
         K = plyr::alply(row.idx, use.mars, function(idx) {
             fq = RG@grid[[".wgt."]][idx]
-            apply(diag(fq) %*% RG@linfct[idx, , drop=FALSE], 2, sum) / sum(fq)
+            apply(.diag(fq) %*% RG@linfct[idx, , drop=FALSE], 2, sum) / sum(fq)
         })
     else
         K = plyr::alply(row.idx, use.mars, function(idx) {
@@ -217,7 +218,8 @@ lsmeans.character.ref.grid = function(object, specs, by = NULL,
     
     RG@roles$responses = character()
     RG@misc$famSize = nrow(linfct)
-    RG@misc$estName = "lsmean"
+    if(RG@misc$estName == "prediction") 
+        RG@misc$estName = "lsmean"
     RG@misc$adjust = "none"
     RG@misc$infer = c(TRUE,FALSE)
     RG@misc$pri.vars = setdiff(facs, by)
@@ -241,7 +243,7 @@ lsmeans.character.ref.grid = function(object, specs, by = NULL,
         # TO DO: provide for passing dots to cld                
             return(cld(result, by = by))
         }
-        ctrs = contrast(result, method = contr, by, ...)
+        ctrs = contrast(result, method = contr, by = by, ...)
         .cls.list("lsm.list", lsmeans = result, contrasts = ctrs)
     }
 }
@@ -252,7 +254,7 @@ lsmeans.character.ref.grid = function(object, specs, by = NULL,
 .find.by = function(rhs) {
     b = strsplit(rhs, "\\|")[[1]]
     if (length(b) > 1) 
-        All.vars(as.formula(paste("~",b[2])))
+        .all.vars(as.formula(paste("~",b[2])))
     else NULL
 }
 
@@ -260,13 +262,47 @@ lsmeans.character.ref.grid = function(object, specs, by = NULL,
 contrast = function(object, ...)
     UseMethod("contrast")
 
-contrast.ref.grid = function(object, method = "eff", by, adjust, offset = NULL,
-        name = "contrast", options = getOption("lsmeans")$contrast, ...) {
+contrast.ref.grid = function(object, method = "eff", interaction = FALSE, 
+        by, adjust, offset = NULL, name = "contrast", 
+        options = getOption("lsmeans")$contrast, ...) 
+{
+    if(missing(by)) 
+        by = object@misc$by.vars
+    if(length(by) == 0) # character(0) --> NULL
+        by = NULL
+
+    if (is.logical(interaction) && interaction)
+        interaction = method
+    if (!is.logical(interaction)) { # i.e., interaction is not FALSE
+        if (!is.character(interaction))
+            stop("interaction requires named contrast function(s)")
+        if(missing(adjust))
+            adjust = "none"
+        by = NULL
+        vars = names(object@levels)
+        k = length(vars)
+        if(!is.null(by)) {
+            vars = c(setdiff(vars, by), by)
+            k = k - length(by)
+        }
+        interaction = rep(interaction, k)[1:k]
+        for (i in k:1) {
+            nm = paste(vars[i], interaction[i], sep = "_")
+            object = contrast.ref.grid(object, interaction[i], by = vars[-i], name = nm)
+            vars[i] = nm
+        }
+        object = update(object, by = by, adjust = adjust, ...)
+        if(!is.null(options)) {
+            options$object = object
+            object = do.call(update.ref.grid, options)
+        }
+        return(object)
+    }
+    
+    # else
     args = object@grid
     args[[".offset."]] = NULL 
     args[[".wgt."]] = NULL # ignore auxiliary stuff in labels, etc.
-    if(missing(by)) 
-        by = object@misc$by.vars
     if (!is.null(by)) {
         by.rows = .find.by.rows(args, by)
         bylevs = args[, by, drop=FALSE]
@@ -298,6 +334,9 @@ contrast.ref.grid = function(object, method = "eff", by, adjust, offset = NULL,
     cmat = method(levs, ...)
     if (!is.data.frame(cmat))
         stop("Contrast function must provide a data.frame")
+    else if(ncol(cmat) == 0)
+        warning("No contrasts were generated! Perhaps only one lsmean is involved.\n",
+             "  This can happen, for example, when your predictors are not factors.")
     else if (nrow(cmat) != nrow(args))
         stop("Nonconforming number of contrast coefficients")
     
@@ -313,7 +352,7 @@ contrast.ref.grid = function(object, method = "eff", by, adjust, offset = NULL,
     # If you ever want to expand to irregular grids, this block will
     # have to change, but everything else is probably OK.
     else {
-        tcmat = kronecker(diag(rep(1,length(by.rows))), t(cmat))
+        tcmat = kronecker(.diag(rep(1,length(by.rows))), t(cmat))
         linfct = tcmat %*% object@linfct[unlist(by.rows), ]
         tmp = expand.grid(con= names(cmat), by = seq_len(length(by.rows)))###unique(by.id))
         grid = data.frame(.contrast. = tmp$con)
@@ -433,7 +472,13 @@ test.ref.grid = function(object, null = 0,
             print(cbind(object@grid, equals = null))
         } 
         L = object@linfct
-        if (!missing(rows))
+        bhat = object@bhat
+        estble.idx = which(!is.na(object@bhat))
+        bhat = bhat[estble.idx]
+        est.flag = !is.na(object@nbasis[1])
+        
+        ### L = L[, estble.idx, drop = FALSE]
+         if (!missing(rows))
             by.rows = list(sel.rows = rows)
         else {
             by.rows = list(all = seq_len(nrow(L)))
@@ -443,44 +488,53 @@ test.ref.grid = function(object, null = 0,
                 by.rows = .find.by.rows(object@grid, by)
         }
         
-        estble.idx = which(!is.na(object@bhat))
-        bhat = object@bhat[estble.idx]
-        ###L = L[, estble.idx, drop = FALSE]
-        lindep = FALSE
-        
+        lindep = nonest = FALSE
+
         result = lapply(by.rows, function(rows) {
             LL = L[rows, , drop = FALSE]
-            if (!all(is.estble(LL, object@nbasis)))
-                c(F = NA, df1 = NA, df2 = NA, p.value = NA)
-            else {
-                LL = LL[, estble.idx, drop = FALSE]
-                # Check rank
-                qrLt = qr(t(LL))
-                r = qrLt$rank
-                if (r < nrow(LL)) {
-                    if(!all(null==0))
-                        stop("Rows are linearly dependent - cannot do the test when 'null' != 0")
-                    else
-                        lindep <<- TRUE
-                }
-                tR = t(qr.R(qrLt))[1:r,1:r]
-                tQ = t(qr.Q(qrLt))[1:r, , drop = FALSE]
-                if(length(null) < r) null = rep(null,r)
-                z = tQ %*% bhat - solve(tR, null[1:r])
-                zcov = tQ %*% object@V %*% t(tQ)
-                F = sum(z * solve(zcov, z)) / r
-                df2 = object@dffun(tQ, object@dfargs)
-                if (is.na(df2))
-                    p.value = pchisq(F*r, r, lower.tail = FALSE)
-                else
-                    p.value = pf(F, r, df2, lower.tail = FALSE)
-                round(c(F = F, df1 = r, df2 = df2, p.value = p.value), 4)
+            # estract est'ble rows
+            if(est.flag) {
+                erows = estimability::is.estble(LL, object@nbasis)
+                nonest <<- nonest || (sum(erows) < nrow(LL))
+                LL = LL[erows, estble.idx, drop = FALSE]
             }
+            # Check rank
+            qrLt = qr(t(LL)) # this will work even if LL has 0 rows
+            r = qrLt$rank
+            if (r == 0)
+                return(c(df1 = 0, df2 = NA, F = NA, p.value = NA))
+            if (r < nrow(LL)) {
+                if(!all(null == 0))
+                    stop("Rows are linearly dependent - cannot do the test when 'null' != 0")
+                else 
+                    lindep <<- TRUE
+            }
+            tR = t(qr.R(qrLt))[1:r, 1:r, drop = FALSE]
+            tQ = t(qr.Q(qrLt))[1:r, , drop = FALSE]
+            if(length(null) < r) null = rep(null, r)
+            z = tQ %*% bhat - solve(tR, null[1:r])
+            zcov = tQ %*% object@V %*% t(tQ)
+            F = sum(z * solve(zcov, z)) / r
+            df2 = object@dffun(tQ, object@dfargs)
+            if (is.na(df2))
+                p.value = pchisq(F*r, r, lower.tail = FALSE)
+            else
+                p.value = pf(F, r, df2, lower.tail = FALSE)
+            c(round(c(df1 = r, df2 = df2), 2), F = round(F, 3), p.value = p.value)
         })
         
+        result = as.data.frame(t(as.data.frame(result)))
+        if (!missing(by)) {
+            fbr = sapply(by.rows, "[", 1)
+            result = cbind(object@grid[fbr, by, drop = FALSE], result)
+        }
+        class(result) = c("summary.ref.grid", "data.frame")
         if (lindep)
-            message("Note: Rows are linearly dependent - df are reduced accordingly")
-        t(as.data.frame(result))
+            message("There are linearly dependent rows - df are reduced accordingly")
+        if (nonest)
+            message("Some rows are non-estimable and were excluded")
+        
+        result
     }
 }
 
@@ -511,7 +565,7 @@ lstrends = function(model, specs, var, delta.var=.01*rng, data, ...) {
     fcn = NULL   # differential
     if (is.null(x)) {
         fcn = var
-        var = All.vars(as.formula(paste("~",var)))
+        var = .all.vars(as.formula(paste("~",var)))
         if (length(var) > 1)
             stop("Can only support a function of one variable")
         else {
@@ -584,7 +638,7 @@ lstrends = function(model, specs, var, delta.var=.01*rng, data, ...) {
 .some.term.contains = function(facs, terms) {
     for (trm in attr(terms, "term.labels")) {
         if(all(sapply(facs, function(f) length(grep(f,trm))>0)))
-            if (length(All.vars(as.formula(paste("~",trm)))) > length(facs)) 
+            if (length(.all.vars(as.formula(paste("~",trm)))) > length(facs)) 
                 return(TRUE)
     }
     return(FALSE)
