@@ -17,6 +17,11 @@
 # 2.13: Revised to call w/ just object instead of all those args (except linfct)
 #   Also moved offset comps to here, and provided for misc$estHook
 .est.se.df = function(object, do.se=TRUE, tol = get.lsm.option("estble.tol")) {
+    if (nrow(object@grid) == 0) {
+        result = data.frame(NA, NA, NA)
+        names(result) = c(object@misc$estName, "SE", "df")
+        return(result[-1, ])
+    }
     misc = object@misc
     if (!is.null(hook <- misc$estHook)) {
         if (is.character(hook)) hook = get(hook)
@@ -45,7 +50,7 @@
     }
     result = as.data.frame(result)
     names(result) = c(misc$estName, "SE", "df")
-    
+
     if (!is.null(misc$tran) && (misc$tran != "none")) {
         if(is.character(misc$tran)) {
             link = try(make.link(misc$tran), silent=TRUE)
@@ -139,8 +144,9 @@
     adj.meths = c("sidak", "tukey", "scheffe", "dunnettx", "mvt", "bonferroni", "none")
     k = pmatch(tolower(adjust), adj.meths)
     if(is.na(k)) {
-        k = which(adj.meths == "none")
-        mesg = "Confidence levels are NOT adjusted for multiplicity"
+        k = which(adj.meths == "bonferroni") ###none")
+        ###mesg = paste("\"", adjust, "\" adjustment is not valid for CIs: used bonferroni instead", sep = "")
+        ###mesg = "Confidence levels are NOT adjusted for multiplicity"
     }
     adjust = adj.meths[k]
     if ((fam.info[3] != 3) && adjust == "tukey") # not pairwise
@@ -389,6 +395,14 @@ summary.ref.grid <- function(object, infer, level, adjust, by, type, df,
     
     mesg = object@misc$initMesg
     
+    ### Add an annotation when we show results on lp scale and
+    ### there is a transformation
+    if (!inv && !is.null(linkName <- object@misc$tran)) {
+        if (!is.character(linkName))
+            linkName = "linear predictor (not response)"
+        mesg = c(mesg, paste("Results are given on the", linkName, "scale."))
+    }
+    
     # et = 1 if a prediction, 2 if a contrast (or unmatched or NULL), 3 if pairs
     et = pmatch(c(object@misc$estType, "c"), c("prediction", "contrast", "pairs"), nomatch = 2)[1]
     
@@ -408,7 +422,7 @@ summary.ref.grid <- function(object, infer, level, adjust, by, type, df,
     
     if(infer[1]) { # add CIs
         acv = .adj.critval(level, result$df, adjust, fam.info, side, corrmat)
-        adjust = acv$adjust
+        ###adjust = acv$adjust # in older versions, I forced same adj method for tests
         cv = acv$cv
         cv = switch(side + 2, cbind(-Inf, cv), cbind(-cv, cv), cbind(-cv, Inf))
         cnm = if (zFlag) c("asymp.LCL", "asymp.UCL") else c("lower.CL","upper.CL")
