@@ -177,14 +177,20 @@ cld(org.vardiff)
 
 
 ###################################################
-### code chunk number 28: using-lsmeans.rnw:342-344
+### code chunk number 28: using-lsmeans.rnw:336-337
+###################################################
+contrast(org.mlsm, interaction = c("poly", "pairwise"))
+
+
+###################################################
+### code chunk number 29: using-lsmeans.rnw:344-346
 ###################################################
 # Ensure we see the same results each time
 set.seed(123454321)
 
 
 ###################################################
-### code chunk number 29: using-lsmeans.rnw:346-349
+### code chunk number 30: using-lsmeans.rnw:348-351
 ###################################################
 library("multcomp")
 days.glht <- as.glht(days_contr.lsm)
@@ -192,39 +198,39 @@ summary(days.glht, test = adjusted("Westfall"))
 
 
 ###################################################
-### code chunk number 30: using-lsmeans.rnw:352-354 (eval = FALSE)
+### code chunk number 31: using-lsmeans.rnw:354-356 (eval = FALSE)
 ###################################################
 ## days.glht1 <- glht(oranges.lm1, 
 ##                    lsm("day", contr = "trt.vs.ctrl", ref = c(5,6)))
 
 
 ###################################################
-### code chunk number 31: using-lsmeans.rnw:358-360 (eval = FALSE)
+### code chunk number 32: using-lsmeans.rnw:360-362 (eval = FALSE)
 ###################################################
 ## summary(days_contr.lsm, adjust = "mvt")
 ## summary(days.glht)
 
 
 ###################################################
-### code chunk number 32: using-lsmeans.rnw:366-367 (eval = FALSE)
+### code chunk number 33: using-lsmeans.rnw:368-369 (eval = FALSE)
 ###################################################
 ## summary(as.glht(pairs(org.lsm)))
 
 
 ###################################################
-### code chunk number 33: using-lsmeans.rnw:370-371 (eval = FALSE)
+### code chunk number 34: using-lsmeans.rnw:372-373 (eval = FALSE)
 ###################################################
 ## summary(as.glht(pairs(org.lsm), by = NULL))
 
 
 ###################################################
-### code chunk number 34: using-lsmeans.rnw:374-375 (eval = FALSE)
+### code chunk number 35: using-lsmeans.rnw:376-377 (eval = FALSE)
 ###################################################
 ## summary(as.glht(pairs(org.lsm, by = NULL)))
 
 
 ###################################################
-### code chunk number 35: using-lsmeans.rnw:387-392
+### code chunk number 36: using-lsmeans.rnw:389-394
 ###################################################
 data("Oats", package = "nlme")
 library("lme4")
@@ -234,88 +240,92 @@ anova(Oats.lmer)
 
 
 ###################################################
-### code chunk number 36: oatcontr (eval = FALSE)
+### code chunk number 37: oatcontr (eval = FALSE)
 ###################################################
+## ### We disable pbkrtest temporarily due to a bug in version 0.4.5.
+## lsm.options(disable.pbkrtest = TRUE) 
 ## contrast(lsmeans(Oats.lmer, "nitro"), "poly")
 
 
 ###################################################
-### code chunk number 37: using-lsmeans.rnw:399-400
+### code chunk number 38: using-lsmeans.rnw:403-404
 ###################################################
 cat("NOTE: Results may be misleading due to involvement in interactions")
 
 
 ###################################################
-### code chunk number 38: using-lsmeans.rnw:402-403
+### code chunk number 39: using-lsmeans.rnw:406-407
 ###################################################
+### We disable pbkrtest temporarily due to a bug in version 0.4.5.
+lsm.options(disable.pbkrtest = TRUE) 
 contrast(lsmeans(Oats.lmer, "nitro"), "poly")
 
 
 ###################################################
-### code chunk number 39: using-lsmeans.rnw:406-408
+### code chunk number 40: using-lsmeans.rnw:410-412
 ###################################################
 Oats.lmer2 <- lmer(log(yield) ~ Variety + poly(nitro,2) 
                                 + (1|Block/Variety),  data = Oats)
 
 
 ###################################################
-### code chunk number 40: using-lsmeans.rnw:411-413
+### code chunk number 41: using-lsmeans.rnw:415-417
 ###################################################
 Oats.lsm2 <- lsmeans(Oats.lmer2, ~ nitro | Variety, cov.reduce = FALSE)
 Oats.lsm2
 
 
 ###################################################
-### code chunk number 41: oatslmer
+### code chunk number 42: oatslmer
 ###################################################
 lsmip(Oats.lmer, Variety ~ nitro, ylab = "Observed log(yield)")
 
 
 ###################################################
-### code chunk number 42: oatslmer2
+### code chunk number 43: oatslmer2
 ###################################################
 lsmip(Oats.lsm2, Variety ~ nitro, ylab = "Predicted log(yield)")
 
 
 ###################################################
-### code chunk number 43: using-lsmeans.rnw:454-455
+### code chunk number 44: using-lsmeans.rnw:458-459
 ###################################################
 str(Oats.lsm2)
 
 
 ###################################################
-### code chunk number 44: using-lsmeans.rnw:458-459
+### code chunk number 45: using-lsmeans.rnw:462-463
 ###################################################
 summary(Oats.lsm2, type = "response")
 
 
 ###################################################
-### code chunk number 45: using-lsmeans.rnw:475-477
+### code chunk number 46: using-lsmeans.rnw:479-481
 ###################################################
 Oats.Vlsm = lsmeans(Oats.lmer2, "Variety")
 test(Oats.Vlsm, null = log(100), type = "response")
 
 
 ###################################################
-### code chunk number 46: using-lsmeans.rnw:489-490
+### code chunk number 47: using-lsmeans.rnw:493-494
 ###################################################
 test(Oats.Vlsm, null = log(100), delta = 0.20, type = "r")
 
 
 ###################################################
-### code chunk number 47: using-lsmeans.rnw:496-497
+### code chunk number 48: using-lsmeans.rnw:500-501
 ###################################################
 test(contrast(Oats.Vlsm, "trt.vs.ctrlk"), side = ">")
 
 
 ###################################################
-### code chunk number 48: using-lsmeans.rnw:500-501
+### code chunk number 49: using-lsmeans.rnw:504-505
 ###################################################
 test(contrast(Oats.Vlsm, "trt.vs.ctrlk"), side = "nonsup", delta = .25)
 
 
 ###################################################
-### code chunk number 49: chick-plot
+### code chunk number 50: chick-plot
 ###################################################
 require("lattice")
 xyplot(weight~Time | Diet, groups = ~ Chick, data = ChickWeight, 
@@ -323,46 +333,52 @@ xyplot(weight~Time | Diet, groups = ~ Chick, data = ChickWeight,
 
 
 ###################################################
-### code chunk number 50: using-lsmeans.rnw:522-524
+### code chunk number 51: using-lsmeans.rnw:526-528
 ###################################################
 Chick.lmer <- lmer(weight ~ Diet * Time + (0 + Time | Chick), 
     data = ChickWeight)
 
 
 ###################################################
-### code chunk number 51: using-lsmeans.rnw:527-528
+### code chunk number 52: using-lsmeans.rnw:531-532
 ###################################################
 ( Chick.lst <- lstrends (Chick.lmer, ~ Diet, var = "Time") )
 
 
 ###################################################
-### code chunk number 52: using-lsmeans.rnw:531-532
+### code chunk number 53: using-lsmeans.rnw:535-536
 ###################################################
 cld (Chick.lst)
 
 
 ###################################################
-### code chunk number 53: using-lsmeans.rnw:543-546
+### code chunk number 54: using-lsmeans.rnw:547-550
 ###################################################
 lsm.options(ref.grid = list(level = .90),
             lsmeans = list(),
-            contrast = list(infer = c(TRUE,TRUE)))
+            contrast = list(infer = c(TRUE, TRUE)))
 
 
 ###################################################
-### code chunk number 54: using-lsmeans.rnw:559-560
+### code chunk number 55: using-lsmeans.rnw:555-556
+###################################################
+get.lsm.option("estble.tol")
+
+
+###################################################
+### code chunk number 56: using-lsmeans.rnw:567-568
 ###################################################
 lsmeans(Oats.lmer2, pairwise ~ Variety)
 
 
 ###################################################
-### code chunk number 55: using-lsmeans.rnw:564-565
+### code chunk number 57: using-lsmeans.rnw:572-573
 ###################################################
 lsm.options(ref.grid = NULL, contrast = NULL)
 
 
 ###################################################
-### code chunk number 56: using-lsmeans.rnw:575-578
+### code chunk number 58: using-lsmeans.rnw:583-586
 ###################################################
 nutr.lm <- lm(gain ~ (age + group + race)^2, data = nutrition)
 library("car")
@@ -370,21 +386,21 @@ Anova(nutr.lm)
 
 
 ###################################################
-### code chunk number 57: nutr-intplot
+### code chunk number 59: nutr-intplot
 ###################################################
 lsmip(nutr.lm, race ~ age | group)
 lsmeans(nutr.lm, ~ group*race)
 
 
 ###################################################
-### code chunk number 58: using-lsmeans.rnw:595-597
+### code chunk number 60: using-lsmeans.rnw:603-605
 ###################################################
 nutr.lsm <- lsmeans(nutr.lm, ~ group * race, weights = "proportional",
     at = list(age = c("2","3"), race = c("Black","White")))
 
 
 ###################################################
-### code chunk number 59: using-lsmeans.rnw:600-603
+### code chunk number 61: using-lsmeans.rnw:608-611
 ###################################################
 nutr.lsm    
 summary(pairs(nutr.lsm, by = "race"), by = NULL)
@@ -392,7 +408,7 @@ summary(pairs(nutr.lsm, by = "group"), by = NULL)
 
 
 ###################################################
-### code chunk number 60: using-lsmeans.rnw:616-620
+### code chunk number 62: using-lsmeans.rnw:624-628
 ###################################################
 lsmeans(nutr.lm, "race", weights = "equal")
 lsmeans(nutr.lm, "race", weights = "prop")
@@ -401,20 +417,20 @@ lsmeans(nutr.lm, "race", weights = "cells")
 
 
 ###################################################
-### code chunk number 61: using-lsmeans.rnw:629-631
+### code chunk number 63: using-lsmeans.rnw:637-639
 ###################################################
 temp = lsmeans(nutr.lm, c("group","race"), weights = "prop")
 lsmeans(temp, "race", weights = "prop")
 
 
 ###################################################
-### code chunk number 62: using-lsmeans.rnw:636-637
+### code chunk number 64: using-lsmeans.rnw:644-645
 ###################################################
 with(nutrition, tapply(gain, race, mean))
 
 
 ###################################################
-### code chunk number 63: using-lsmeans.rnw:644-648
+### code chunk number 65: using-lsmeans.rnw:652-656
 ###################################################
 library("mediation")
 levels(framing$educ) = c("NA","Ref","< HS", "HS", "> HS","Coll +")
@@ -423,34 +439,34 @@ framing.glm = glm(cong_mesg ~ age + income + educ + emo + gender * factor(treat)
 
 
 ###################################################
-### code chunk number 64: framinga
+### code chunk number 66: framinga
 ###################################################
 lsmip(framing.glm, treat ~ educ | gender, type = "response")
 
 
 ###################################################
-### code chunk number 65: framingb
+### code chunk number 67: framingb
 ###################################################
 lsmip(framing.glm, treat ~ educ | gender, type = "response",
       cov.reduce = emo ~ treat*gender + age + educ + income)
 
 
 ###################################################
-### code chunk number 66: using-lsmeans.rnw:675-677
+### code chunk number 68: using-lsmeans.rnw:683-685
 ###################################################
 ref.grid(framing.glm, 
     cov.reduce = emo ~ treat*gender + age + educ + income)@grid
 
 
 ###################################################
-### code chunk number 67: using-lsmeans.rnw:708-710 (eval = FALSE)
+### code chunk number 69: using-lsmeans.rnw:716-718 (eval = FALSE)
 ###################################################
 ## rg <- ref.grid(my.model, at = list(x1 = c(5,10,15)),
 ##                cov.reduce = list(x2 ~ x1,  x3 ~ x1 + x2))
 
 
 ###################################################
-### code chunk number 68: housing-plot
+### code chunk number 70: housing-plot
 ###################################################
 library("ordinal")
 data(housing, package = "MASS")
@@ -460,39 +476,39 @@ lsmip(housing.clm, Cont ~ Infl | Type, layout = c(4,1))
 
 
 ###################################################
-### code chunk number 69: using-lsmeans.rnw:755-756
+### code chunk number 71: using-lsmeans.rnw:763-764
 ###################################################
 test(pairs(lsmeans(housing.clm, ~ Infl | Type)), joint = TRUE)
 
 
 ###################################################
-### code chunk number 70: using-lsmeans.rnw:759-760
+### code chunk number 72: using-lsmeans.rnw:767-768
 ###################################################
 test(pairs(lsmeans(housing.clm, ~ Cont | Type)), joint = TRUE)
 
 
 ###################################################
-### code chunk number 71: using-lsmeans.rnw:765-766
+### code chunk number 73: using-lsmeans.rnw:773-774
 ###################################################
 ref.grid(housing.clm, mode = "cum.prob")
 
 
 ###################################################
-### code chunk number 72: using-lsmeans.rnw:769-771
+### code chunk number 74: using-lsmeans.rnw:777-779
 ###################################################
 lsmeans(housing.clm, ~ Infl, at = list(cut = "Medium|High"), 
         mode = "cum.prob")
 
 
 ###################################################
-### code chunk number 73: using-lsmeans.rnw:774-776
+### code chunk number 75: using-lsmeans.rnw:782-784
 ###################################################
 summary(lsmeans(housing.clm, ~ Infl, at = list(cut = "Medium|High"), 
                 mode = "linear.predictor"), type = "response")
 
 
 ###################################################
-### code chunk number 74: using-lsmeans.rnw:784-792
+### code chunk number 76: using-lsmeans.rnw:792-800
 ###################################################
 require("nlme")
 options(contrasts = c("contr.treatment", "contr.poly"))
@@ -505,14 +521,14 @@ Chick.nlme
 
 
 ###################################################
-### code chunk number 75: using-lsmeans.rnw:795-797
+### code chunk number 77: using-lsmeans.rnw:803-805
 ###################################################
 cld(lsmeans(Chick.nlme, ~ Diet, param = "asym"))    
 cld(lsmeans(Chick.nlme, ~ Diet, param = "xmid"))    
 
 
 ###################################################
-### code chunk number 76: using-lsmeans.rnw:809-814
+### code chunk number 78: using-lsmeans.rnw:817-822
 ###################################################
 library("MCMCpack")
 counts <- c(18, 17, 15,   20, 10, 20,   25, 13, 12)
@@ -522,13 +538,13 @@ posterior <- MCMCpoisson(counts ~ outcome + treatment, mcmc = 1000)
 
 
 ###################################################
-### code chunk number 77: using-lsmeans.rnw:817-818
+### code chunk number 79: using-lsmeans.rnw:825-826
 ###################################################
 ( post.lsm <- lsmeans(posterior, "treatment") )
 
 
 ###################################################
-### code chunk number 78: using-lsmeans.rnw:821-823
+### code chunk number 80: using-lsmeans.rnw:829-831
 ###################################################
 library("coda")
 summary(as.mcmc(post.lsm))
